@@ -1,5 +1,6 @@
 from fwiffos.core import version
 from fwiffos.cli.sudo import LetUs
+from fwiffos.read.gsheets import GSheets
 
 class Calculator(object):
 
@@ -22,6 +23,7 @@ class Commands(object):
         fs = FS()
         calc = Calculator()
         sudo = LetUs()
+        gsheets = GSheets()
         self._version = version
         self.__commands = {
             'ls': fs.ls,
@@ -29,6 +31,7 @@ class Commands(object):
             'mult': calc.multiply,
             'sudo': sudo.letus,
             'letus': sudo.letus,
+            'read': gsheets,
         }
 
     def exec(self):
